@@ -1,8 +1,11 @@
 """Top-level package for PrettyQt."""
+import pathlib
 
 __author__ = """Philipp Temminghoff"""
 __email__ = "phil65@kodi.tv"
-__version__ = "0.166.0"
+__version__ = "0.177.1"
+
+ROOT_PATH = pathlib.Path(__file__).parent
 
 
 def debug():
