@@ -5,9 +5,13 @@ Contains QtCore-based classes
 
 # from prettyqt.qt.QtCore import Signal
 
+from __future__ import annotations
+
+from typing import List, Optional
+
 import prettyqt.qt
 
-from prettyqt.qt.QtCore import (
+from prettyqt.qt.QtCore import (  # type: ignore
     Slot,
     Signal,
     Property,
@@ -21,7 +25,17 @@ from prettyqt.qt.QtCore import (
     QChildEvent as ChildEvent,
     QTimerEvent as TimerEvent,
     QDynamicPropertyChangeEvent as DynamicPropertyChangeEvent,
+    QtCriticalMsg as CriticalMsg,
+    QtDebugMsg as DebugMsg,
+    QtFatalMsg as FatalMsg,
+    QtInfoMsg as InfoMsg,
+    QtMsgType as MsgType,
+    QtSystemMsg as SystemMsg,
+    QtWarningMsg as WarningMsg,
 )
+from .metaenum import MetaEnum
+from .metamethod import MetaMethod
+from .metaobject import MetaObject
 from .persistentmodelindex import PersistentModelIndex
 from .cryptographichash import CryptographicHash
 from .uuid import Uuid
@@ -66,6 +80,7 @@ from .urlquery import UrlQuery
 from .translator import Translator
 from .coreapplication import CoreApplication
 from .filesystemwatcher import FileSystemWatcher
+from .fileselector import FileSelector
 from .iodevice import IODevice
 from .filedevice import FileDevice
 from .file import File
@@ -149,10 +164,11 @@ if VersionNumber.get_qt_version() < (6, 0, 0):
     from .statemachine import StateMachine
 
 
-def app():
-    if CoreApplication.instance() is not None:
-        return CoreApplication.instance()
-    return CoreApplication([])
+def app(args: Optional[List[str]] = None) -> CoreApplication:
+    instance = CoreApplication.instance()
+    if instance is not None:
+        return instance
+    return CoreApplication([] if args is None else args)
 
 
 __all__ = [
@@ -161,6 +177,9 @@ __all__ = [
     "ChildEvent",
     "TimerEvent",
     "DynamicPropertyChangeEvent",
+    "MetaEnum",
+    "MetaMethod",
+    "MetaObject",
     "Object",
     "CryptographicHash",
     "Uuid",
@@ -191,6 +210,7 @@ __all__ = [
     "UrlQuery",
     "CoreApplication",
     "FileSystemWatcher",
+    "FileSelector",
     "IODevice",
     "FileDevice",
     "File",
@@ -274,4 +294,11 @@ __all__ = [
     "Collator",
     "JsonValue",
     "JsonDocument",
+    "CriticalMsg",
+    "DebugMsg",
+    "FatalMsg",
+    "InfoMsg",
+    "MsgType",
+    "SystemMsg",
+    "WarningMsg",
 ]
