@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+import os
 import pathlib
 from typing import Any
 
@@ -7,8 +10,8 @@ from prettyqt.qt import QtCore
 
 class FileInfo(QtCore.QFileInfo):
     def __init__(self, *args, **kwargs):
-        if len(args) == 1 and isinstance(args[0], pathlib.Path):
-            super().__init__(str(args[0]))
+        if len(args) == 1 and isinstance(args[0], os.PathLike):  # type: ignore
+            super().__init__(os.fspath(args[0]))
         else:
             super().__init__(*args, **kwargs)
 
@@ -18,6 +21,9 @@ class FileInfo(QtCore.QFileInfo):
     def __str__(self):
         return self.absoluteFilePath()
 
+    def __fspath__(self) -> str:
+        return self.absoluteFilePath()
+
     def __getattr__(self, attr: str) -> Any:
         return getattr(self.get_absolute_file_path(), attr)
 
