@@ -1,12 +1,12 @@
-from typing import Any, Dict, Iterator, List, Union
+from __future__ import annotations
+
+from typing import Any, Iterator, List, Union
 
 import orjson as json
 
 from prettyqt import core
 from prettyqt.qt import QtCore
-
-
-JSONType = Union[str, int, float, bool, None, Dict[str, Any], List[Any]]
+from prettyqt.utils import types
 
 
 QtCore.QMimeData.__bases__ = (core.Object,)
@@ -36,13 +36,13 @@ class MimeData(QtCore.QMimeData):
     def set_data(self, mime_type: str, data: str):
         self.setData(mime_type, QtCore.QByteArray(data.encode()))
 
-    def set_json_data(self, mime_type: str, data: JSONType):
+    def set_json_data(self, mime_type: str, data: types.JSONType):
         self.setData(mime_type, QtCore.QByteArray(json.dumps(data, option=OPTS)))
 
     def get_data(self, mime_type: str) -> str:
         return bytes(self.data(mime_type)).decode()
 
-    def get_json_data(self, mime_type: str) -> JSONType:
+    def get_json_data(self, mime_type: str) -> types.JSONType:
         data = self.data(mime_type)
         return json.loads(bytes(data))
 
@@ -51,3 +51,7 @@ class MimeData(QtCore.QMimeData):
 
     def values(self) -> Iterator[Any]:
         return (self.get_data(key) for key in self.formats())
+
+
+if __name__ == "__main__":
+    mime_data = MimeData()
