@@ -1,4 +1,6 @@
-from typing import Literal
+from __future__ import annotations
+
+from typing import Iterator, Literal, Union
 
 from prettyqt.qt import QtCore
 from prettyqt.utils import InvalidParamError, bidict
@@ -107,6 +109,18 @@ class TextStream(QtCore.QTextStream):
         """
         return REAL_NUMBER_NOTATION.inverse[self.realNumberNotation()]
 
+    def set_codec(self, codec: Union[bytes, str]):
+        if isinstance(codec, str):
+            codec = codec.encode()
+        self.setCodec(codec)
+
+    def read_lines(self) -> Iterator[str]:
+        while True:
+            msg = self.readLine()
+            if not msg:
+                return
+            yield msg
+
 
 if __name__ == "__main__":
     stream = TextStream(QtCore.QByteArray(b"Test"))
