@@ -1,22 +1,32 @@
-from typing import Callable, Union
+from __future__ import annotations
+
+from typing import Callable, Iterator, Tuple, Union
 
 from prettyqt import core
 from prettyqt.qt import QtCore
+from prettyqt.utils import types
 
 
 QtCore.QVariantAnimation.__bases__ = (core.AbstractAnimation,)
 
 
 class VariantAnimation(QtCore.QVariantAnimation):
-    def __len__(self):
-        return self.duration()
-
-    def __getitem__(self, value: float):
+    def __getitem__(self, value: float) -> types.Variant:
         return self.keyValueAt(value)
 
-    def __setitem__(self, key: float, value):
+    def __setitem__(self, key: float, value: types.Variant):
         self.setKeyValueAt(key, value)
 
+    def __iter__(self) -> Iterator[Tuple[float, types.Variant]]:
+        return iter(self.keyValues())
+
+    def serialize_fields(self):
+        return dict(
+            duration=self.duration(),
+            easing_curve=self.get_easing(),
+            key_values=self.keyValues(),
+        )
+
     def set_easing(
         self, easing_type: Union[core.easingcurve.TypeStr, Callable[[float], float]]
     ):
@@ -34,3 +44,7 @@ class VariantAnimation(QtCore.QVariantAnimation):
             return curve.get_custom_type()
         else:
             return typ
+
+    def set_range(self, start, end):
+        self.setStartValue(start)
+        self.setEndValue(end)
