@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-import pathlib
+import os
 from typing import Optional, Union
 
 from prettyqt import gui, widgets
@@ -10,7 +10,7 @@ from prettyqt.qt import QtWidgets
 class Image(widgets.Label):
     def __init__(
         self,
-        path: Union[pathlib.Path, str] = None,
+        path: Union[os.PathLike, str] = None,
         parent: Optional[QtWidgets.QWidget] = None,
     ):
         super().__init__(parent=parent)
@@ -20,18 +20,18 @@ class Image(widgets.Label):
     def __repr__(self):
         return f"{type(self).__name__}()"
 
-    def set_image(self, path: Union[pathlib.Path, str], width: int = 300):
+    def set_image(self, path: Union[os.PathLike, str], width: int = 300):
         self.setScaledContents(True)
         self.set_alignment(horizontal="center")
         self.setText(
             "<html><head/><body><p>"
-            f"<img src={str(path)!r} width={str(width)!r}/>"
+            f"<img src={os.fspath(path)!r} width={str(width)!r}/>"
             "</p></body></html>"
         )
 
     @classmethod
     def from_path(
-        cls, path: Union[pathlib.Path, str], parent: Optional[QtWidgets.QWidget] = None
+        cls, path: Union[os.PathLike, str], parent: Optional[QtWidgets.QWidget] = None
     ) -> Image:
         pixmap = gui.Pixmap.from_file(path)
         label = cls(parent=parent)
