@@ -1,4 +1,6 @@
-import pathlib
+from __future__ import annotations
+
+import os
 from typing import Optional, Union
 
 from prettyqt import widgets
@@ -9,7 +11,7 @@ class ImageViewer(widgets.Widget):
     def __init__(
         self,
         title: str = "",
-        path: Union[pathlib.Path, str] = None,
+        path: Union[os.PathLike, str] = None,
         parent: Optional[QtWidgets.QWidget] = None,
     ):
         super().__init__(parent)
