@@ -2,6 +2,9 @@
 
 Contains QtGui-based classes
 """
+from __future__ import annotations
+
+from typing import List, Optional
 
 from prettyqt.qt.QtGui import (
     QKeyEvent as KeyEvent,
@@ -43,6 +46,7 @@ from prettyqt.qt.QtGui import (
 # not available in PySide2
 # from prettyqt.qt.QtGui import QPlatformSurfaceEvent as PlatformSurfaceEvent
 
+from .textobjectinterface import TextObjectInterface
 from .screen import Screen
 from .keysequence import KeySequence
 from .surface import Surface
@@ -63,6 +67,7 @@ from .sessionmanager import SessionManager
 from .validator import Validator
 
 from .regularexpressionvalidator import RegularExpressionValidator
+from .textlayout import TextLayout
 from .textline import TextLine
 from .textoption import TextOption
 from .textblock import TextBlock
@@ -128,10 +133,11 @@ if core.VersionNumber.get_qt_version() >= (5, 13, 0):
     from .colorspace import ColorSpace
 
 
-def app():
-    if GuiApplication.instance() is not None:
-        return GuiApplication.instance()
-    return GuiApplication([])
+def app(args: Optional[List[str]] = None) -> GuiApplication:
+    instance = GuiApplication.instance()
+    if instance is not None:
+        return instance
+    return GuiApplication([] if args is None else args)
 
 
 __all__ = [
@@ -146,6 +152,7 @@ __all__ = [
     "NativeGestureEvent",
     "InputMethodQueryEvent",
     "InputMethodEvent",
+    "TextObjectInterface",
     "SessionManager",
     "CloseEvent",
     "DragLeaveEvent",
@@ -182,6 +189,7 @@ __all__ = [
     "Clipboard",
     "GuiApplication",
     "Validator",
+    "TextLayout",
     "TextLine",
     "TextOption",
     "TextBlock",
