@@ -1,4 +1,6 @@
-import pathlib
+from __future__ import annotations
+
+import os
 from typing import List, Literal, Optional, Tuple, Union
 
 from prettyqt import core, gui
@@ -36,7 +38,7 @@ class IconEngine(QtGui.QIconEngine):
 
     def add_file(
         self,
-        path: Union[str, pathlib.Path],
+        path: Union[str, os.PathLike],
         size: Union[QtCore.QSize, Tuple[int, int], int],
         mode: gui.icon.ModeStr,
         state: gui.icon.StateStr,
@@ -49,7 +51,7 @@ class IconEngine(QtGui.QIconEngine):
             size = core.Size(*size)
         elif isinstance(size, int):
             size = core.Size(size, size)
-        self.addFile(str(path), size, gui.icon.MODE[mode], gui.icon.STATE[state])
+        self.addFile(os.fspath(path), size, gui.icon.MODE[mode], gui.icon.STATE[state])
 
     def add_pixmap(
         self,
@@ -119,8 +121,6 @@ class IconEngine(QtGui.QIconEngine):
 
 
 if __name__ == "__main__":
-    from prettyqt import gui
-
     app = gui.app()
     engine = IconEngine()
     print(repr(engine))
