@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import os
 import pathlib
 from typing import Union
 
@@ -37,9 +38,8 @@ class Pixmap(QtGui.QPixmap):
         return self.cacheKey()
 
     @classmethod
-    def from_file(cls, path: Union[pathlib.Path, str]):
-        if isinstance(path, str):
-            path = pathlib.Path(path)
+    def from_file(cls, path: Union[os.PathLike, str]) -> Pixmap:
+        path = pathlib.Path(path)
         with path.open(mode="rb") as f:
             data = f.read()
         # Create widget
@@ -53,7 +53,7 @@ class Pixmap(QtGui.QPixmap):
     def get_rect(self) -> core.Rect:
         return core.Rect(self.rect())
 
-    def to_image(self):  # -> gui.Image:
+    def to_image(self) -> gui.Image:
         return gui.Image(self.toImage())
 
     @classmethod
