@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import Union
+
 from prettyqt import core, gui
 from prettyqt.qt import QtGui
 
@@ -23,9 +27,10 @@ class RegularExpressionValidator(QtGui.QRegularExpressionValidator):
             return False
         return self.regularExpression() == other.regularExpression()
 
-    def set_regex(self, regex: str, flags=0):
-        re = core.RegularExpression(regex, flags)
-        self.setRegularExpression(re)
+    def set_regex(self, regex: Union[str, core.RegularExpression], flags=0):
+        if isinstance(regex, str):
+            regex = core.RegularExpression(regex, flags)
+        self.setRegularExpression(regex)
 
     def get_regex(self) -> str:
         val = self.regularExpression()
