@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import os
 from typing import Iterator, List, Optional, Tuple, Union
 
 from prettyqt import constants, core, gui, iconprovider
@@ -16,7 +17,7 @@ class StandardItem(QtGui.QStandardItem):
             text=self.text(),
             tool_tip=self.toolTip(),
             status_tip=self.statusTip(),
-            icon=gui.Icon(self.icon()) if not self.icon().isNull() else None,
+            icon=self.get_icon(),
             data=self.data(),
         )
 
@@ -115,8 +116,26 @@ class StandardItem(QtGui.QStandardItem):
     def get_font(self) -> gui.Font:
         return gui.Font(self.font())
 
-    def get_icon(self) -> gui.Icon:
-        return gui.Icon(self.icon())
+    def get_icon(self) -> Optional[gui.Icon]:
+        icon = self.icon()
+        if icon.isNull():
+            return None
+        return gui.Icon(icon)
+
+    def set_tooltip(
+        self,
+        tooltip: Union[str, os.PathLike],
+        size: Optional[Union[Tuple[int, int], QtCore.QSize]] = None,
+    ):
+        if isinstance(tooltip, os.PathLike):  # type: ignore
+            path = os.fspath(tooltip)
+            if size is None:
+                tooltip = f"<img src={path!r}>"
+            else:
+                if isinstance(size, QtCore.QSize):
+                    size = (size.width(), size.height())
+                tooltip = f'<img src={path!r} width="{size[0]}" height="{size[1]}">'
+        self.setToolTip(tooltip)
 
     def add_item(
         self,
