@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import Optional
+
 from prettyqt import location
 from prettyqt.qt import QtLocation
 
@@ -9,8 +13,11 @@ class PlaceCategory(QtLocation.QPlaceCategory):
     def __bool__(self):
         return not self.isEmpty()
 
-    def get_icon(self) -> location.PlaceIcon:
-        return location.PlaceIcon(self.icon())
+    def get_icon(self) -> Optional[location.PlaceIcon]:
+        icon = self.icon()
+        if icon.isEmpty():
+            return None
+        return location.PlaceIcon(icon)
 
     def get_visibility(self) -> location.VisibilityStr:
         """Return the visibility of the place.
@@ -22,5 +29,5 @@ class PlaceCategory(QtLocation.QPlaceCategory):
 
 
 if __name__ == "__main__":
-    segment = PlaceCategory()
-    print(bool(segment))
+    category = PlaceCategory()
+    print(bool(category))
