@@ -1,4 +1,6 @@
-from typing import Union
+from __future__ import annotations
+
+from typing import Optional, Union
 
 from prettyqt import core, location
 from prettyqt.qt import QtCore, QtLocation
@@ -8,8 +10,11 @@ class PlaceSupplier(QtLocation.QPlaceSupplier):
     def __bool__(self):
         return not self.isEmpty()
 
-    def get_icon(self) -> location.PlaceIcon:
-        return location.PlaceIcon(self.icon())
+    def get_icon(self) -> Optional[location.PlaceIcon]:
+        icon = self.icon()
+        if icon.isEmpty():
+            return None
+        return location.PlaceIcon(icon)
 
     def set_url(self, url: Union[str, QtCore.QUrl]):
         url = core.Url(url)
