@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """Multimediawidgets module."""
 
 from prettyqt import core
@@ -7,8 +5,6 @@ from prettyqt import core
 if core.VersionNumber.get_qt_version() >= (5, 13, 0):
     from .videowidgetcontrol import VideoWidgetControl
 from .videowidget import VideoWidget
+from .graphicsvideoitem import GraphicsVideoItem
 
-__all__ = [
-    "VideoWidgetControl",
-    "VideoWidget",
-]
+__all__ = ["VideoWidgetControl", "VideoWidget", "GraphicsVideoItem"]
