@@ -5,9 +5,6 @@ See: https://github.com/PySide/Examples/blob/master/examples/itemviews/simpletre
      /simpletreemodel.py
 """
 
-# TODO: a lot of methods (e.g. rowCount) test if parent.column() > 0. This should probably
-# be replaced with an assert.
-
 from __future__ import annotations
 
 from collections import OrderedDict
@@ -21,6 +18,10 @@ from prettyqt.qt import QtCore
 from prettyqt.utils import helpers, treeitem
 
 
+# TODO: a lot of methods (e.g. rowCount) test if parent.column() > 0. This should probably
+# be replaced with an assert.
+
+
 logger = logging.getLogger(__name__)
 
 MAX_OBJ_STR_LEN = 50
@@ -110,7 +111,7 @@ class ObjectBrowserTreeModel(custom_models.ColumnItemModel):
     def flags(self, index: core.ModelIndex):
         if not index.isValid():
             return constants.NO_CHILDREN
-        return constants.IS_ENABLED | constants.IS_SELECTABLE
+        return constants.IS_ENABLED | constants.IS_SELECTABLE  # type: ignore
 
     def index(
         self, row: int, column: int, parent: Optional[core.ModelIndex] = None
