@@ -3,6 +3,7 @@
 Contains QtQml-based classes
 """
 
+from prettyqt.qt.QtQml import qmlRegisterType as register_qml_type
 from .qmlparserstatus import QmlParserStatus
 from .jsvalue import JSValue
 from .jsvalueiterator import JSValueIterator
@@ -13,6 +14,7 @@ from .qmlcomponent import QmlComponent
 from .qmlimageproviderbase import QmlImageProviderBase
 
 __all__ = [
+    "register_qml_type",
     "QmlParserStatus",
     "JSValue",
     "JSValueIterator",
