@@ -1,7 +1,10 @@
+from __future__ import annotations
+
+import os
 import pathlib
 from typing import List, Literal, Union
 
-from prettyqt import qml
+from prettyqt import core, qml
 from prettyqt.qt import QtCore, QtQml
 from prettyqt.utils import InvalidParamError, bidict
 
@@ -38,14 +41,25 @@ class QmlEngine(QtQml.QQmlEngine):
         """
         return OBJECT_OWNERSHIP.inverse[self.objectOwnership(obj)]
 
-    def add_import_path(self, path: Union[str, pathlib.Path]):
-        self.addImportPath(str(path))
+    def add_import_path(self, path: Union[str, os.PathLike]):
+        self.addImportPath(os.fspath(path))
 
-    def add_plugin_path(self, path: Union[str, pathlib.Path]):
-        self.addPluginPath(str(path))
+    def add_plugin_path(self, path: Union[str, os.PathLike]):
+        self.addPluginPath(os.fspath(path))
 
     def get_plugin_paths(self) -> List[pathlib.Path]:
         return [pathlib.Path(p) for p in self.pluginPathList()]
 
     def get_import_paths(self) -> List[pathlib.Path]:
         return [pathlib.Path(p) for p in self.importPathList()]
+
+    def set_base_url(self, url: Union[str, QtCore.QUrl]):
+        if isinstance(url, str):
+            url = QtCore.QUrl(url)
+        self.setBaseUrl(url)
+
+    def get_base_url(self) -> core.Url:
+        return core.Url(self.baseUrl())
+
+    def set_offline_storage_path(self, path: Union[str, os.PathLike]):
+        self.setOfflineStoragePath(os.fspath(path))
