@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+import os
 import pathlib
 from typing import Literal, Union
 
@@ -26,9 +29,9 @@ QtQuick.QQuickView.__bases__ = (gui.Window,)
 
 
 class QuickView(QtQuick.QQuickView):
-    def set_source(self, source: Union[str, pathlib.Path, QtCore.QUrl]):
-        if isinstance(source, pathlib.Path):
-            source = str(source)
+    def set_source(self, source: Union[str, os.PathLike, QtCore.QUrl]):
+        if isinstance(source, os.PathLike):  # type: ignore
+            source = os.fspath(source)
         if isinstance(source, str):
             source = core.Url.fromLocalFile(source)
         self.setSource(source)
