@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import List, Optional, Tuple
+
 from prettyqt import gui
 
 
@@ -10,14 +14,14 @@ FORMAT_2.set_background_color("lightblue")
 class RegexMatchHighlighter(gui.SyntaxHighlighter):
     def __init__(self, document=None):
         super().__init__(document)
-        self.spans = []
+        self.spans: Optional[List[Tuple[int, int]]] = []
 
-    def set_spans(self, spans):
+    def set_spans(self, spans: Optional[List[Tuple[int, int]]]):
         self.spans = spans
         # print(self.spans)
         self.rehighlight()
 
-    def _colorize(self, line_pos, match_len, match_num):
+    def _colorize(self, line_pos: int, match_len: int, match_num: int):
         fmt = FORMAT_1 if match_num % 2 == 0 else FORMAT_2
         self.setFormat(line_pos, match_len, fmt)
 
