@@ -1,7 +1,27 @@
+from __future__ import annotations
+
+from datetime import timedelta
 import functools
 import operator
+import re
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping
+
+
+REGEX = re.compile(
+    r"((?P<hours>\d+?)h)?((?P<minutes>\d+?)m)?"
+    r"((?P<seconds>\d+?)s)?((?P<milliseconds>\d+?)ms)?"
+)
+
+
+def parse_time(time_str: str) -> int:
+    parts = REGEX.match(time_str)
+    if not parts:
+        raise ValueError(time_str)
+    dct = parts.groupdict()
+    time_params = {name: int(param) for (name, param) in dct.items() if param}
+    secs = timedelta(**time_params).total_seconds()
+    return int(secs) * 1000
 
 
 def string_to_num_array(array: str) -> List[float]:
@@ -9,7 +29,7 @@ def string_to_num_array(array: str) -> List[float]:
     return [int(i) if i.is_integer() else i for i in floats]
 
 
-def merge_flags(flags, mapping):
+def merge_flags(flags, mapping: Mapping):
     return functools.reduce(operator.ior, [mapping[t] for t in flags])
 
 
@@ -18,7 +38,7 @@ def format_kwargs(kwargs: Dict[str, Any]) -> str:
     return ", ".join(kwarg_list)
 
 
-def cut_off_str(obj, max_len: int):
+def cut_off_str(obj, max_len: int) -> str:
     """Create a string representation of an object, no longer than max_len characters.
 
     Uses repr(obj) to create the string representation. If this is longer than max_len -3
