@@ -3,6 +3,10 @@
 contains QtWidgets-based classes
 """
 
+from __future__ import annotations
+
+from typing import List, Optional
+
 from prettyqt import core
 from prettyqt.qt.QtWidgets import (
     QGraphicsSceneHoverEvent as GraphicsSceneHoverEvent,
@@ -24,6 +28,7 @@ from .application import Application
 from .sizepolicy import SizePolicy
 from .widget import Widget
 from .frame import Frame
+from .focusframe import FocusFrame
 from .abstractslider import AbstractSlider
 from .abstractscrollarea import AbstractScrollArea
 from .abstractbutton import AbstractButton
@@ -166,6 +171,7 @@ from .styleditemdelegate import StyledItemDelegate
 from .systemtrayicon import SystemTrayIcon
 
 from .layoutitem import LayoutItem
+from .widgetitem import WidgetItem
 from .layout import Layout
 from .spaceritem import SpacerItem
 from .formlayout import FormLayout
@@ -182,6 +188,7 @@ from .colordialog import ColorDialog
 from .inputdialog import InputDialog
 from .buttongroup import ButtonGroup
 from .groupbox import GroupBox
+from .splitterhandle import SplitterHandle
 from .splitter import Splitter
 from .wizard import Wizard
 from .wizardpage import WizardPage
@@ -201,12 +208,16 @@ from .pangesture import PanGesture
 from .pinchgesture import PinchGesture
 from .swipegesture import SwipeGesture
 
+from .itemeditorcreatorbase import ItemEditorCreatorBase
+from .itemeditorfactory import ItemEditorFactory
 
-def app():
-    if Application.instance() is not None:
-        return Application.instance()
+
+def app(args: Optional[List[str]] = None) -> Application:
+    instance = Application.instance()
+    if instance is not None:
+        return instance
     Application.disable_window_help_button()
-    return Application([])
+    return Application([] if args is None else args)
 
 
 __all__ = [
@@ -269,6 +280,7 @@ __all__ = [
     "FileIconProvider",
     "FileSystemModel",
     "LayoutItem",
+    "WidgetItem",
     "Layout",
     "FormLayout",
     "BoxLayout",
@@ -300,6 +312,7 @@ __all__ = [
     "StyleOptionToolButton",
     "StyleOptionFrame",
     "Frame",
+    "FocusFrame",
     "ListWidgetItem",
     "TreeWidgetItem",
     "TreeWidgetItemIterator",
@@ -357,6 +370,7 @@ __all__ = [
     "DialogButtonBox",
     "ButtonGroup",
     "GroupBox",
+    "SplitterHandle",
     "Splitter",
     "Wizard",
     "WizardPage",
@@ -393,4 +407,6 @@ __all__ = [
     "PanGesture",
     "PinchGesture",
     "SwipeGesture",
+    "ItemEditorFactory",
+    "ItemEditorCreatorBase",
 ]
