@@ -1,4 +1,7 @@
-from typing import Callable, Literal, Optional, Union
+from __future__ import annotations
+
+import os
+from typing import Callable, Literal, Optional, Tuple, Union
 
 from prettyqt import constants, core, gui, iconprovider
 from prettyqt.qt import QtCore, QtGui, QtWidgets
@@ -73,12 +76,12 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
             text=self.text(),
             enabled=self.isEnabled(),
             visible=self.isVisible(),
-            font=gui.Font(self.font()),
+            font=self.get_font(),
             shortcut=self.get_shortcut(),
             tool_tip=self.toolTip(),
             checkable=self.isCheckable(),
             checked=self.isChecked(),
-            icon=gui.Icon(self.icon()) if not self.icon().isNull() else None,
+            icon=self.get_icon(),
             icon_text=self.iconText(),
             priority=self.get_priority(),
             icon_visible_in_menu=self.isIconVisibleInMenu(),
@@ -127,8 +130,20 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
     def set_disabled(self):
         self.setEnabled(False)
 
-    def set_tooltip(self, text: str):
-        self.setToolTip(text)
+    def set_tooltip(
+        self,
+        tooltip: Union[str, os.PathLike],
+        size: Optional[Union[Tuple[int, int], QtCore.QSize]] = None,
+    ):
+        if isinstance(tooltip, os.PathLike):  # type: ignore
+            path = os.fspath(tooltip)
+            if size is None:
+                tooltip = f"<img src={path!r}>"
+            else:
+                if isinstance(size, QtCore.QSize):
+                    size = (size.width(), size.height())
+                tooltip = f'<img src={path!r} width="{size[0]}" height="{size[1]}">'
+        self.setToolTip(tooltip)
 
     def set_statustip(self, text: str):
         self.setStatusTip(text)
@@ -148,6 +163,12 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
         icon = iconprovider.get_icon(icon)
         self.setIcon(icon)
 
+    def get_icon(self) -> Optional[gui.Icon]:
+        icon = self.icon()
+        if icon.isNull():
+            return None
+        return gui.Icon(icon)
+
     def set_shortcut(self, shortcut: Union[None, QtGui.QKeySequence, str]):
         if shortcut is None:
             shortcut = ""
@@ -161,6 +182,9 @@ class Action(prettyprinter.PrettyPrinter, QtWidgets.QAction):
             return None
         return gui.KeySequence(shortcut.toString(), gui.KeySequence.PortableText)
 
+    def get_font(self) -> gui.Font:
+        return gui.Font(self.font())
+
     def set_menu(self, menu):
         try:
             self.setMenu(menu)
