@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Callable, Iterator, Literal, Optional, Sequence, Union
 
 from prettyqt import constants, core, widgets
@@ -93,8 +95,8 @@ class DialogButtonBox(QtWidgets.QDialogButtonBox):
     def __iter__(self) -> Iterator[QtWidgets.QAbstractButton]:
         return iter(self.buttons())
 
-    def __contains__(self, item: ButtonStr):
-        return self[item] is not None
+    def __contains__(self, index: ButtonStr):
+        return self.button(BUTTONS[index]) is not None
 
     @classmethod
     def create(cls, **kwargs):
