@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+import os
 import pathlib
 from typing import Iterator, List, Sequence, Union
 
@@ -32,6 +35,12 @@ class FileSystemModel(QtWidgets.QFileSystemModel):
             return pathlib.Path(path)
         return super().data(index, role)
 
+    def get_file_info(self, index: QtCore.QModelIndex) -> core.FileInfo:
+        return core.FileInfo(self.fileInfo(index))
+
+    def get_file_path(self, index: QtCore.QModelIndex) -> pathlib.Path:
+        return pathlib.Path(self.filePath(index))
+
     def yield_child_indexes(
         self, index: QtCore.QModelIndex
     ) -> Iterator[QtCore.QModelIndex]:
@@ -51,8 +60,8 @@ class FileSystemModel(QtWidgets.QFileSystemModel):
     def use_custom_icons(self, use: bool):
         self.setOption(OPTIONS["no_custom_icons"], not use)
 
-    def set_root_path(self, path: Union[str, pathlib.Path]):
-        path = str(path)
+    def set_root_path(self, path: Union[str, os.PathLike]) -> QtCore.QModelIndex:
+        path = os.fspath(path)
         if path in ["/", "root"]:
             path = core.Dir.rootPath()
         elif path == "home":
@@ -61,7 +70,7 @@ class FileSystemModel(QtWidgets.QFileSystemModel):
             path = core.Dir.tempPath()
         elif path == "current":
             path = core.Dir.currentPath()
-        self.setRootPath(path)
+        return self.setRootPath(path)
 
     def set_name_filters(self, filters, hide: bool = False):
         self.setNameFilters(filters)
@@ -84,3 +93,16 @@ class FileSystemModel(QtWidgets.QFileSystemModel):
                 if (folder / filename).is_file()
             ]
         return paths
+
+
+if __name__ == "__main__":
+    from prettyqt import widgets
+
+    app = widgets.app()
+    app.load_language("de")
+    model = FileSystemModel()
+    model.set_root_path("root")
+    tree = widgets.TreeView()
+    tree.set_model(model)
+    tree.show()
+    app.main_loop()
