@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import List, Literal, Optional, Union
 
 from prettyqt import constants, core, widgets
@@ -48,8 +50,8 @@ class Layout(QtWidgets.QLayout):
     def __iter__(self):
         return iter(self[i] for i in range(self.count()))
 
-    def __contains__(self, item: Union[QtWidgets.QWidget, QtWidgets.QLayout]):
-        return item in self.get_children()
+    def __contains__(self, item: Union[QtWidgets.QWidget, QtWidgets.QLayoutItem]):
+        return self.indexOf(item) >= 0
 
     def serialize_fields(self):
         return dict(
