@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Any, Iterable, Iterator, List, Mapping, Optional, Union
 
 from prettyqt import constants, core, iconprovider, widgets
@@ -27,7 +29,10 @@ class ListWidget(QtWidgets.QListWidget):
         return f"{type(self).__name__}: {self.count()} items"
 
     def __getitem__(self, row: int) -> QtWidgets.QListWidgetItem:
-        return self.item(row)
+        item = self.item(row)
+        if item is None:
+            raise KeyError(row)
+        return item
 
     def __delitem__(self, row: int):
         self.takeItem(row)
@@ -159,7 +164,7 @@ class ListWidget(QtWidgets.QListWidget):
 
 
 if __name__ == "__main__":
-    app = QtWidgets.QApplication([])
+    app = widgets.app()
     widget = ListWidget()
     widget.add("test", icon="mdi.timer")
     widget.add("test", icon="mdi.timer")
