@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Iterator, List, Optional, Union
 
 from prettyqt import constants, widgets
@@ -59,6 +61,9 @@ class Splitter(QtWidgets.QSplitter):
     def __len__(self) -> int:
         return self.count()
 
+    def __contains__(self, item: QtWidgets.QWidget):
+        return self.indexOf(item) >= 0
+
     def __add__(self, other: Union[QtWidgets.QWidget, QtWidgets.QLayout]):
         self.add(other)
         return self
@@ -117,7 +122,7 @@ class Splitter(QtWidgets.QSplitter):
 
 
 if __name__ == "__main__":
-    app = QtWidgets.QApplication([])
+    app = widgets.app()
     widget = Splitter()
     widget.show()
     app.main_loop()
