@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Tuple
 
 from prettyqt import widgets
@@ -9,7 +11,10 @@ QtWidgets.QTableWidget.__bases__ = (widgets.TableView,)
 
 class TableWidget(QtWidgets.QTableWidget):
     def __getitem__(self, index: Tuple[int, int]) -> QtWidgets.QTableWidgetItem:
-        return self.item(*index)
+        item = self.item(*index)
+        if item is None:
+            raise KeyError(index)
+        return item
 
     def __setitem__(self, index: Tuple[int, int], value: QtWidgets.QTableWidgetItem):
         self.setItem(index[0], index[1], value)
@@ -23,7 +28,7 @@ class TableWidget(QtWidgets.QTableWidget):
 
 
 if __name__ == "__main__":
-    app = QtWidgets.QApplication([])
+    app = widgets.app()
     widget = TableWidget()
     widget.setHorizontalHeaderLabels(["testus"])
     widget.setColumnCount(1)
