@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Optional
 
 from prettyqt import constants, gui, iconprovider
@@ -18,7 +20,7 @@ class TableWidgetItem(QtWidgets.QTableWidgetItem):
             tool_tip=self.toolTip(),
             status_tip=self.statusTip(),
             checkstate=self.get_checkstate(),
-            icon=gui.Icon(self.icon()) if not self.icon().isNull() else None,
+            icon=self.get_icon(),
             data=self.data(QtCore.Qt.UserRole),
         )
 
@@ -60,7 +62,8 @@ class TableWidgetItem(QtWidgets.QTableWidgetItem):
         """Set text alignment of the checkbox.
 
         Args:
-            alignment: text alignment to use
+            horizontal: horizontal text alignment to use
+            vertical: vertical text alignment to use
 
         Raises:
             InvalidParamError: invalid text alignment
@@ -84,8 +87,11 @@ class TableWidgetItem(QtWidgets.QTableWidgetItem):
     def get_font(self) -> gui.Font:
         return gui.Font(self.font())
 
-    def get_icon(self) -> gui.Icon:
-        return gui.Icon(self.icon())
+    def get_icon(self) -> Optional[gui.Icon]:
+        icon = self.icon()
+        if icon.isNull():
+            return None
+        return gui.Icon(icon)
 
 
 if __name__ == "__main__":
