@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Dict, List, Literal, Optional, Tuple, Union
 
 from prettyqt import core, gui, iconprovider, widgets
@@ -59,6 +61,9 @@ class TabWidget(QtWidgets.QTabWidget):
                 raise KeyError("Widget not found")
             return result
 
+    def __contains__(self, item: QtWidgets.QWidget):
+        return self.indexOf(item) >= 0
+
     def serialize_fields(self):
         return dict(
             tabbar=self.tabBar(),
@@ -153,8 +158,11 @@ class TabWidget(QtWidgets.QTabWidget):
             for i in range(self.count())
         ]
 
-    def tab_icon(self, i: int) -> gui.Icon:
-        return gui.Icon(self.tabIcon(i))
+    def tab_icon(self, i: int) -> Optional[gui.Icon]:
+        icon = self.tabIcon(i)
+        if icon.isNull():
+            return None
+        return gui.Icon(icon)
 
     def set_detachable(self):
         self.tab_bar.on_detach.connect(self.detach_tab)
@@ -179,8 +187,8 @@ class TabWidget(QtWidgets.QTabWidget):
         if isinstance(point, tuple):
             point = QtCore.QPoint(*point)
         name = self.tabText(index)
-        icon = self.tabIcon(index)
-        if icon.isNull():
+        icon = self.tab_icon(index)
+        if icon is None:
             icon = self.window().windowIcon()
         widget = self.widget(index)
 
