@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from typing import Optional
 
 from prettyqt import constants, widgets
@@ -24,6 +26,21 @@ class TreeView(QtWidgets.QTreeView):
         self.h_header = widgets.HeaderView("horizontal", parent=self)
         self.set_selection_mode("extended")
 
+    def serialize_fields(self):
+        return dict(
+            all_columns_show_focus=self.allColumnsShowFocus(),
+            animated=self.isAnimated(),
+            auto_expand_delay=self.autoExpandDelay(),
+            expands_on_double_click=self.expandsOnDoubleClick(),
+            header_hidden=self.isHeaderHidden(),
+            indentation=self.indentation(),
+            items_expandable=self.itemsExpandable(),
+            root_is_decorated=self.rootIsDecorated(),
+            sorting_enabled=self.isSortingEnabled(),
+            uniform_row_heights=self.uniformRowHeights(),
+            word_wrap=self.wordWrap(),
+        )
+
     @property
     def h_header(self):
         return self.header()
@@ -56,8 +73,8 @@ class TreeView(QtWidgets.QTreeView):
 
 
 if __name__ == "__main__":
-    app = QtWidgets.QApplication([])
-    dlg = QtWidgets.QMainWindow()
+    app = widgets.app()
+    dlg = widgets.MainWindow()
     status_bar = TreeView()
     dlg.show()
     app.main_loop()
