@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Iterator, Literal
+from typing import Iterator, Literal, Optional
 
 from prettyqt import constants, core, gui, iconprovider
 from prettyqt.qt import QtCore, QtWidgets
@@ -21,13 +21,12 @@ class TreeWidgetItem(QtWidgets.QTreeWidgetItem):
         return f"{type(self).__name__}()"
 
     def serialize_fields(self):
-        icon = self.icon(0)
         return dict(
             text=[self.text(i) for i in range(self.columnCount())],
             tool_tip=[self.toolTip(i) for i in range(self.columnCount())],
             status_tip=[self.statusTip(i) for i in range(self.columnCount())],
             checkstate=[self.get_checkstate(i) for i in range(self.columnCount())],
-            icon=gui.Icon(icon) if not icon.isNull() else None,
+            icon=[self.get_icon(i) for i in range(self.columnCount())],
             data=[self.data(i, QtCore.Qt.UserRole) for i in range(self.columnCount())],
         )
 
@@ -51,7 +50,10 @@ class TreeWidgetItem(QtWidgets.QTreeWidgetItem):
         return self.childCount()
 
     def __getitem__(self, index: int) -> QtWidgets.QTreeWidgetItem:
-        return self.child(index)
+        item = self.child(index)
+        if item is None:
+            raise KeyError(index)
+        return item
 
     def __delitem__(self, index: int):
         self.takeChild(index)
@@ -83,8 +85,11 @@ class TreeWidgetItem(QtWidgets.QTreeWidgetItem):
     def get_font(self, column: int = 0) -> gui.Font:
         return gui.Font(self.font(column))
 
-    def get_icon(self, column: int = 0) -> gui.Icon:
-        return gui.Icon(self.icon(column))
+    def get_icon(self, column: int = 0) -> Optional[gui.Icon]:
+        icon = self.icon(column)
+        if icon.isNull():
+            return None
+        return gui.Icon(icon)
 
     def set_checkstate(self, state: constants.StateStr, column: int = 0):
         """Set checkstate of the checkbox.
