@@ -1,5 +1,10 @@
+from __future__ import annotations
+
 import contextlib
-from typing import Any, Callable, Dict, Iterator, Literal, Optional, Union
+import os
+import pathlib
+import sys
+from typing import Any, Callable, Dict, Iterator, Literal, Optional, Tuple, Union
 
 from deprecated import deprecated
 import qstylizer.parser
@@ -32,9 +37,13 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
         self.setToolTip(state.get("tool_tip", ""))
         self.setToolTipDuration(state.get("tooltip_duration", ""))
         self.setWindowTitle(state.get("window_title", ""))
-        self.setEnabled(state.get("enabled", ""))
-        self.setVisible(state.get("visible", ""))
-        self.set_icon(state.get("icon", ""))
+        self.setWindowFilePath(state.get("window_file_path", ""))
+        self.setEnabled(state.get("enabled", True))
+        self.setVisible(state.get("visible", True))
+        self.setTabletTracking(state.get("tablet_tracking", True))
+        self.setWindowModified(state.get("window_modified", False))
+        self.setWindowOpacity(state.get("window_opacity", 1.0))
+        self.set_icon(state.get("icon"))
         self.set_modality(state.get("modality", ""))
         self.setWhatsThis(state.get("whats_this", ""))
         self.set_contextmenu_policy(state.get("contextmenu_policy", ""))
@@ -42,24 +51,30 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
         self.setStatusTip(state.get("status_tip", ""))
         self.setStyleSheet(state.get("stylesheet", ""))
         self.setFont(state.get("font", ""))
+        if state["is_maximized"]:
+            self.showMaximized()
 
     def __reduce__(self):
         return type(self), (), self.__getstate__()
 
     def serialize_fields(self) -> Dict[str, Any]:
-        icon = gui.Icon(self.windowIcon())
         return dict(
             layout=self.layout() if isinstance(self.layout(), widgets.Layout) else None,
             size_policy=self.get_size_policy(),
+            is_maximized=self.isMaximized(),
             actions=self.actions(),
             accessible_name=self.accessibleName(),
             tool_tip=self.toolTip(),
             tooltip_duration=self.toolTipDuration(),
             window_title=self.windowTitle(),
+            window_file_path=self.windowFilePath(),
             enabled=self.isEnabled(),
+            tablet_tracking=self.hasTabletTracking(),
+            window_modified=self.isWindowModified(),
+            window_opacity=self.windowOpacity(),
             visible=self.isVisible(),
             stylesheet=self.styleSheet(),
-            icon=icon if not icon.isNull() else None,
+            icon=self.get_icon(),
             modality=self.get_modality(),
             whats_this=self.whatsThis(),
             contextmenu_policy=self.get_contextmenu_policy(),
@@ -74,6 +89,22 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
         else:
             super().resize(*size)
 
+    def raise_to_top(self):
+        if sys.platform.startswith("win"):
+            import win32con
+            from win32gui import SetWindowPos
+
+            # set to always-on-top and disable it again. that way windows stays in front
+            flag = win32con.SWP_NOMOVE | win32con.SWP_NOSIZE | win32con.SWP_SHOWWINDOW
+            win_id = self.winId()
+            SetWindowPos(win_id, win32con.HWND_TOPMOST, 0, 0, 0, 0, flag)
+            SetWindowPos(win_id, win32con.HWND_NOTOPMOST, 0, 0, 0, 0, flag)
+        # state = (self.windowState() & ~Qt.WindowMinimized) | Qt.WindowActive
+        # self.setWindowState(state)
+        self.raise_()
+        self.show()
+        self.activateWindow()
+
     def set_icon(self, icon: types.IconType) -> None:
         """Set the window icon.
 
@@ -83,6 +114,12 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
         icon = iconprovider.get_icon(icon, color=colors.WINDOW_ICON_COLOR)
         self.setWindowIcon(icon)
 
+    def get_icon(self) -> Optional[gui.Icon]:
+        icon = self.windowIcon()
+        if icon.isNull():
+            return None
+        return gui.Icon(self.windowIcon())
+
     def set_min_size(self, *size) -> None:
         self.setMinimumSize(*size)
 
@@ -137,8 +174,20 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
     def get_title(self) -> str:
         return self.windowTitle()
 
-    def set_tooltip(self, text: str) -> None:
-        self.setToolTip(text)
+    def set_tooltip(
+        self,
+        tooltip: Union[str, os.PathLike],
+        size: Optional[Union[Tuple[int, int], QtCore.QSize]] = None,
+    ):
+        if isinstance(tooltip, os.PathLike):  # type: ignore
+            path = os.fspath(tooltip)
+            if size is None:
+                tooltip = f"<img src={path!r}>"
+            else:
+                if isinstance(size, QtCore.QSize):
+                    size = (size.width(), size.height())
+                tooltip = f'<img src={path!r} width="{size[0]}" height="{size[1]}">'
+        self.setToolTip(tooltip)
 
     def set_font(
         self,
@@ -189,6 +238,7 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
         stay_on_top: Optional[bool] = None,
         frameless: Optional[bool] = None,
         window: Optional[bool] = None,
+        tooltip: Optional[bool] = None,
     ) -> None:
         if minimize is not None:
             self.setWindowFlag(QtCore.Qt.WindowMinimizeButtonHint, minimize)
@@ -202,6 +252,8 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
             self.setWindowFlag(QtCore.Qt.FramelessWindowHint, frameless)
         if window is not None:
             self.setWindowFlag(QtCore.Qt.Window, window)
+        if tooltip is not None:
+            self.setWindowFlag(QtCore.Qt.ToolTip, tooltip)
 
     def set_attribute(
         self, attribute: constants.WidgetAttributeStr, state: bool = True
@@ -288,7 +340,13 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
         yield ss
         self.set_stylesheet(ss)
 
-    def set_stylesheet(self, ss: Union[str, qstylizer.style.StyleSheet]):
+    def set_stylesheet(
+        self, ss: Union[None, str, qstylizer.style.StyleSheet, os.PathLike]
+    ):
+        if isinstance(ss, os.PathLike):  # type: ignore
+            ss = pathlib.Path(ss).read_text()
+        elif ss is None:
+            ss = ""
         self.setStyleSheet(str(ss))
 
     def get_stylesheet(self) -> qstylizer.style.StyleSheet:
@@ -462,9 +520,19 @@ class Widget(prettyprinter.PrettyPrinter, QtWidgets.QWidget):
     ):
         self.setMask(gui.Region(x, y, width, height, gui.region.REGION_TYPE[typ]))
 
+    def set_window_file_path(self, path: Union[str, os.PathLike]):
+        self.setWindowFilePath(os.fspath(path))
+
+    def get_window_file_path(self) -> Optional[pathlib.Path]:
+        path = self.windowFilePath()
+        if not path:
+            return None
+        return pathlib.Path(path)
+
 
 if __name__ == "__main__":
-    app = QtWidgets.QApplication([])
+    app = widgets.app()
     widget = Widget()
+    print(type(widget.windowFilePath()))
     widget.show()
     app.main_loop()
