@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Iterator, Literal
+from typing import Iterator, Literal, Optional
 
 from prettyqt import core, gui, widgets
 from prettyqt.qt import QtCore, QtGui, QtWidgets
@@ -101,12 +101,17 @@ QtWidgets.QWizard.__bases__ = (widgets.BaseDialog,)
 
 class Wizard(QtWidgets.QWizard):
     def __getitem__(self, key: int) -> QtWidgets.QWizardPage:
-        return self.page(key)
+        p = self.page(key)
+        if p is None:
+            raise KeyError(key)
+        return p
 
     def __setitem__(self, key: int, value: QtWidgets.QWizardPage):
         return self.setPage(key, value)
 
     def __delitem__(self, key: int):
+        if key not in self.pageIds():
+            raise KeyError(key)
         return self.removePage(key)
 
     def __iter__(self) -> Iterator[QtWidgets.QWizardPage]:
@@ -202,15 +207,20 @@ class Wizard(QtWidgets.QWizard):
             raise InvalidParamError(button_type, WIZARD_BUTTON)
         return self.buttonText(WIZARD_BUTTON[button_type])
 
-    def set_pixmap(self, typ: WizardPixmapStr, pixmap: QtGui.QPixmap):
+    def set_pixmap(self, typ: WizardPixmapStr, pixmap: Optional[QtGui.QPixmap]):
         if typ not in WIZARD_PIXMAP:
             raise InvalidParamError(typ, WIZARD_PIXMAP)
+        if pixmap is None:
+            pixmap = QtGui.QPixmap()
         self.setPixmap(WIZARD_PIXMAP[typ], pixmap)
 
-    def get_pixmap(self, typ: WizardPixmapStr) -> gui.Pixmap:
+    def get_pixmap(self, typ: WizardPixmapStr) -> Optional[gui.Pixmap]:
         if typ not in WIZARD_PIXMAP:
             raise InvalidParamError(typ, WIZARD_PIXMAP)
-        return gui.Pixmap(self.pixmap(WIZARD_PIXMAP[typ]))
+        pix = gui.Pixmap(self.pixmap(WIZARD_PIXMAP[typ]))
+        if pix.isNull():
+            return None
+        return pix
 
     def set_wizard_style(self, style: WizardStyleStr):
         """Set the wizard style.
