@@ -1,5 +1,7 @@
-import pathlib
-from typing import Literal, Optional, Union
+from __future__ import annotations
+
+import os
+from typing import Iterator, Literal, Optional, Union
 
 from prettyqt import iconprovider
 from prettyqt.qt import QtWinExtras
@@ -26,11 +28,14 @@ class WinJumpListCategory(QtWinExtras.QWinJumpListCategory):
     def __bool__(self):
         return not self.isEmpty()
 
+    def __iter__(self) -> Iterator[QtWinExtras.QWinJumpListItem]:
+        return iter(self.items())
+
     def get_type(self) -> TypeStr:
         return TYPES.inverse[self.type()]
 
-    def add_destination(self, destination: Union[str, pathlib.Path]) -> None:
-        self.addDestination(str(destination))
+    def add_destination(self, destination: Union[str, os.PathLike]) -> None:
+        self.addDestination(os.fspath(destination))
 
     def set_title(self, title: str) -> None:
         self.setTitle(title)
@@ -38,14 +43,14 @@ class WinJumpListCategory(QtWinExtras.QWinJumpListCategory):
     def add_link(
         self,
         title: str,
-        exe_path: Union[str, pathlib.Path],
+        exe_path: Union[str, os.PathLike],
         arguments: Optional[list] = None,
         icon: types.IconType = None,
     ) -> None:
         icon = iconprovider.get_icon(icon)
         if arguments is None:
             arguments = []
-        self.addLink(icon, title, str(exe_path), arguments)
+        self.addLink(icon, title, os.fspath(exe_path), arguments)
 
 
 if __name__ == "__main__":
