@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+import os
 import pathlib
 from typing import Literal, Union
 
@@ -30,14 +33,14 @@ class WinJumpListItem(QtWinExtras.QWinJumpListItem):
         icon = iconprovider.get_icon(icon)
         self.setIcon(icon)
 
-    def set_file_path(self, path: Union[str, pathlib.Path]) -> None:
-        self.setFilePath(str(path))
+    def set_file_path(self, path: Union[str, os.PathLike]) -> None:
+        self.setFilePath(os.fspath(path))
 
     def get_file_path(self) -> pathlib.Path:
         return pathlib.Path(self.filePath())
 
-    def set_working_directory(self, path: Union[str, pathlib.Path]) -> None:
-        self.setWorkingDirectory(str(path))
+    def set_working_directory(self, path: Union[str, os.PathLike]) -> None:
+        self.setWorkingDirectory(os.fspath(path))
 
     def get_working_directory(self) -> pathlib.Path:
         return pathlib.Path(self.workingDirectory())
